@@ -1,8 +1,8 @@
 package WebService::GData::Feed;
-use WebService::GData;
+use WebService::GData 'private';
 use base 'WebService::GData';
 
-our $VERSION  = 0.01_01;
+our $VERSION  = 0.01_02;
 
 	sub __init {
 		my ($this,$feed,$auth) = @_;
@@ -110,7 +110,7 @@ our $VERSION  = 0.01_01;
 		return \@ret;
 	}	
 
-	sub _get_feed_type {
+	private _get_feed_type => sub {
 		my $this = shift;
 
 		my $feedTypeString = '';
@@ -122,7 +122,7 @@ our $VERSION  = 0.01_01;
 		my $feedType  = (split('#',$feedTypeString))[1];
 		   $feedType  = "\u$feedType";#Uppercase to load the proper class
 		return $feedType;
-	}
+	};
 
 
 "The earth is blue like an orange.";
@@ -136,113 +136,127 @@ __END__
 
 WebService::GData::Feed - Abstract class wrapping json atom feed for google data API v2.
 
-=head1 VERSION
-
-0.01
-
 =head1 SYNOPSIS
 
-	use WebService::GData::Feed;
+    use WebService::GData::Feed;
 
-    #create an object that only has read access
-   	my $feed = new WebService::GData::Feed($jsonfeed,$auth);
+    my $feed = new WebService::GData::Feed($jsonfeed);
 
     $feed->title;
-	$feed->author;
-	my @entries = $feed->entry();#send back WebService::GData::Feed::Entry or a service related Entry object 
+    $feed->author;
+    my @entries = $feed->entry();#send back WebService::GData::Feed::Entry or a service related Entry object 
 
 
 
 =head1 DESCRIPTION
 
-inherits from WebService::GData;
+I<inherits from L<WebService::GData>>
 
 This package wraps the result from a query to a feed using the json format of the Google Data API v2 (no other format is supported!).
-
 It gives you access to some of the data via wrapper methods and works as a factory to get access to the entries for each service.
-
 If you use a YouTube service, calling the entry() method will send you back YouTube::Feed::Entry's. 
-
 If you use a Calendar service, calling the entry() method will send you back a Calendar::Feed::Entry.
-
 By default, it returns a WebService::GData::Feed::Entry which gives you only a read access to the data.
-
 Unless you implement a service, you should never instantiate this class directly.
 
-=head1 METHODS
+=head2 CONSTRUCTOR
 
 
-=head2 new
+=head3 new
 
 =over
 
-Accept a json feed entry that has been perlified (from_json($json_string)) and an auth object.
+Create a L<WebService::GData::Feed> instance.
 
+Accept a json feed entry that has been perlified (from_json($json_string)) and an optional auth object.
 The auth object is passed along each entries classes but the Feed class itself does not use it.
 
+B<Parameters>
 
-=head2 title
+=over 4
+
+=item C<json_feed:Object> - a json feed perlified
+
+=item C<auth:Object> - an authorization object like L<WebService::GData::ClientLogin>
+
+=back
+
+B<Returns> 
+
+=over 4
+
+=item C<WebService::GData::Feed>
+
+=back
+
+=back
+
+=head2 SET/GET METHODS
+
+All the following methods work as both setter and getters.
+
+=head3 title
 
 =over
 
 set/get the title of the feed.
 
-=head2 updated
+=head3 updated
 
 =over
 
 get the last updated date of the feed.
 
 
-=head2 category
+=head3 category
 
 =over
 
 Get the categories of the feed in a array reference containing hash references with scheme/term keys.
 
-=head2 etag
+=head3 etag
 
 =over
 
 Get the etag of the feed.
 
-=head2 author
+=head3 author
 
 =over
 
 Get the author of the feed.
 
-=head2 total_items
+=head3 total_items
 
 =over
 
 Get the total result of the feed.
 
-=head2 total_results
+=head3 total_results
 
 =over
 
 Get the total result of the feed. Alias for total_items
 
-=head2 start_index
+=head3 start_index
 
 =over
 
 Get the start number of the feed.
 
-=head2 items_per_page
+=head3 items_per_page
 
 =over
 
 Get the the link of items per page.
 
-=head2 links
+=head3 links
 
 =over
 
 Get the links of the feed in a array reference containing hash references with rel/type/href keys.	
 
-=head2 link
+=head3 link
 
 =over
 
@@ -256,23 +270,21 @@ Example:
     my $batch_url= my $feed->get_link('batch');
 
 
-=head2 previous_link
+=head3 previous_link
 
 =over
 
 Get a the previous link if set or undef.
 
-=head2 next_link
+=head3 next_link
 
 =over
 
 Get a the next link if set or undef.
 
-entry
 
 
-
-=head2 entry
+=head3 entry
 
 =over
 
@@ -283,21 +295,6 @@ It works as a factory by instantiating the proper Feed::* class.
 ie,if you read a Video feed from a youtube service, it will instantiate the WebService::GData::Youtube::Feed::Video class and feed it the result.
 
 
-=head1  CONFIGURATION AND ENVIRONMENT
-
-none
-
-
-=head1  DEPENDENCIES
-
-L<JSON>
-
-L<LWP>
-
-=head1  INCOMPATIBILITIES
-
-none
-
 =head1 BUGS AND LIMITATIONS
 
 If you do me the favor to _use_ this module and find a bug, please email me
@@ -305,7 +302,7 @@ i will try to do my best to fix it (patches welcome)!
 
 =head1 AUTHOR
 
-shiriru E<lt>shiriru0111[arobas]hotmail.comE<gt>
+shiriru E<lt>shirirulestheworld[arobas]gmail.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
